#
# spec file for package python-calmjs.parse
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-calmjs.parse
Version:        1.3.3
Release:        1.1
Summary:        Various parsers for ECMA standards
License:        MIT
URL:            https://github.com/calmjs/calmjs.parse
Source:         https://github.com/calmjs/calmjs.parse/archive/%{version}.tar.gz
BuildRequires:  %{python_module ply >= 3.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ply >= 3.6
Requires:       python-setuptools
BuildArch:      noarch
%python_subpackages

%description
A collection of parsers and helper libraries for understanding
ECMAScript; a near feature complete fork of slimit.

%prep
%setup -q -n calmjs.parse-%{version}

%build
export LANG=en_US.UTF-8
%python_build
%python_expand PYTHONPATH=build/lib $python -m calmjs.parse.parsers.optimize

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pyunittest -v calmjs.parse.tests.make_suite

%files %{python_files}
%doc README.rst CHANGES.rst
%license LICENSE
%{python_sitelib}/calmjs*

%changelog
* Mon Feb  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.3.3
  * Revert the usage of ``lru_cache`` as that isn't being hit as expected,
    and that the benefits it brings is too negligible to bring back given
    the extremely limited cache hits.
* Tue Oct 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  * Ensure building from source tree under Python 3.13 works.
  * Dropped support for building under Python 2 in source tree. [
    [#44] ]
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.1:
  * Modified existing ``setup.py`` hook from an install hook to a
    build hook to ensure the generated module files are present.
    Should any of those modules are missing and the required
    dependencies for are not present (i.e. ``ply`` and
    ``setuptools``), the build will result in a
    non-zero exit status and the documented error message should
    reflect which of the required dependencies are missing.
* Fri Jun 23 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed Nov 17 2021 Matej Cepl <mcepl@suse.com>
- Generated tables should get correct *.pyc files
- And no, this won't work with Python 2 modules. Just don't even
  try.
* Tue Nov 16 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.3.0:
  - Introduce the extractor unparser - an unparser that will
    unparse a valid AST into a dict.
  - Correct the JoinAttr ruletype such that the intended empty
    definition value is passed to walk if it was defined as such
    to avoid an unintended infinite recursion.
  - Will now import Iterable from the Python 3.3+ location as the
    previous location is marked for removal in Python 3.9. The import
    will still have a fallback to the previous location in order to
    maintain support for Python 2.7.
  - Provide a test case helper to ensure that the generic Program repr
    signature is provided to assist with test case portability.
  - In the calmjs.parse.vlq module, implemented the decode_vlq helper
    for completeness/symmetry to the encode_vlq helper.
* Mon Mar 30 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.2.4
  * Correct usage of ``__doc__`` to support level 2 optimized mode.
  * Corrected some minor string definition syntax, where raw string prefix
    should be used but was not previously.
  * Correctly include LICENSE file in sdist.
  * Include the correct test data general form for some previously added
    test cases to better accommodate already planned future features.
* Tue Jan 14 2020 pgajdos@suse.com
- fix build in SLE-15: set en_US.UTF-8 encoding
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not package tests
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by calmjs
